==> arduino-esp32-2.0.1.tgz: share/arduino/hardware/espressif/esp32/variants/nina_w10/pins_arduino.h <==
#ifndef Pins_Arduino_h
#define Pins_Arduino_h

#include <stdint.h>

#define EXTERNAL_NUM_INTERRUPTS 16
#define NUM_DIGITAL_PINS        40
#define NUM_ANALOG_INPUTS       16

#define analogInputToDigitalPin(p)  (((p)<20)?(esp32_adc2gpio[(p)]):-1)
#define digitalPinToInterrupt(p)    (((p)<40)?(p):-1)
#define digitalPinHasPWM(p)         (p < 34)

static const uint8_t LED_GREEN = 33;
static const uint8_t LED_RED = 23;
static const uint8_t LED_BLUE = 21;
static const uint8_t SW1 = 33;
static const uint8_t SW2 = 27;

static const uint8_t TX = 1;
static const uint8_t RX = 3;

static const uint8_t SDA = 12;
static const uint8_t SCL = 13;

static const uint8_t SS    = 5;
static const uint8_t MOSI  = 23;
static const uint8_t MISO  = 19;
static const uint8_t SCK   = 18;

static const uint8_t A0 = 36;
static const uint8_t A3 = 39;
static const uint8_t A4 = 32;
static const uint8_t A5 = 33;
static const uint8_t A6 = 34;
static const uint8_t A7 = 35;
static const uint8_t A10 = 4;
static const uint8_t A11 = 0;
static const uint8_t A12 = 2;
static const uint8_t A13 = 15;
static const uint8_t A14 = 13;
static const uint8_t A15 = 12;
static const uint8_t A16 = 14;
static const uint8_t A17 = 27;
static const uint8_t A18 = 25;
static const uint8_t A19 = 26;

static const uint8_t D0 = 3;
static const uint8_t D1 = 1;
static const uint8_t D2 = 26;
static const uint8_t D3 = 25;
static const uint8_t D4 = 35;
static const uint8_t D5 = 27;
static const uint8_t D6 = 22;
static const uint8_t D7 = 0;
static const uint8_t D8 = 15;
static const uint8_t D9 = 14;
static const uint8_t D10 = 5;
static const uint8_t D11 = 19;
static const uint8_t D12 = 23;
static const uint8_t D13 = 18;
static const uint8_t D14 = 13;
static const uint8_t D15 = 12;

static const uint8_t D16 = 32;
static const uint8_t D17 = 33;
static const uint8_t D18 = 21;
static const uint8_t D19 = 34;
static const uint8_t D20 = 36;
static const uint8_t D21 = 39;

static const uint8_t T0 = 4;
static const uint8_t T1 = 0;
static const uint8_t T2 = 2;
static const uint8_t T3 = 15;
static const uint8_t T4 = 13;
static const uint8_t T5 = 12;
static const uint8_t T6 = 14;
static const uint8_t T7 = 27;
static const uint8_t T8 = 33;
static const uint8_t T9 = 32;

static const uint8_t DAC1 = 25;
static const uint8_t DAC2 = 26;

#endif /* Pins_Arduino_h */

==> arduino-esp32-2.0.4p4.tgz: share/arduino/hardware/espressif/esp32/variants/nina_w10/pins_arduino.h <==
#ifndef Pins_Arduino_h
#define Pins_Arduino_h

#include <stdint.h>

#define EXTERNAL_NUM_INTERRUPTS 16
#define NUM_DIGITAL_PINS        40
#define NUM_ANALOG_INPUTS       16

#define analogInputToDigitalPin(p)  (((p)<20)?(analogChannelToDigitalPin(p)):-1)
#define digitalPinToInterrupt(p)    (((p)<40)?(p):-1)
#define digitalPinHasPWM(p)         (p < 34)

static const uint8_t LED_GREEN = 33;
static const uint8_t LED_RED = 23;
static const uint8_t LED_BLUE = 21;
static const uint8_t SW1 = 33;
static const uint8_t SW2 = 27;

static const uint8_t TX = 1;
static const uint8_t RX = 3;

static const uint8_t SDA = 12;
static const uint8_t SCL = 13;

static const uint8_t SS    = 5;
static const uint8_t MOSI  = 23;
static const uint8_t MISO  = 19;
static const uint8_t SCK   = 18;

static const uint8_t A0 = 36;
static const uint8_t A3 = 39;
static const uint8_t A4 = 32;
static const uint8_t A5 = 33;
static const uint8_t A6 = 34;
static const uint8_t A7 = 35;
static const uint8_t A10 = 4;
static const uint8_t A11 = 0;
static const uint8_t A12 = 2;
static const uint8_t A13 = 15;
static const uint8_t A14 = 13;
static const uint8_t A15 = 12;
static const uint8_t A16 = 14;
static const uint8_t A17 = 27;
static const uint8_t A18 = 25;
static const uint8_t A19 = 26;

static const uint8_t D0 = 3;
static const uint8_t D1 = 1;
static const uint8_t D2 = 26;
static const uint8_t D3 = 25;
static const uint8_t D4 = 35;
static const uint8_t D5 = 27;
static const uint8_t D6 = 22;
static const uint8_t D7 = 0;
static const uint8_t D8 = 15;
static const uint8_t D9 = 14;
static const uint8_t D10 = 5;
static const uint8_t D11 = 19;
static const uint8_t D12 = 23;
static const uint8_t D13 = 18;
static const uint8_t D14 = 13;
static const uint8_t D15 = 12;

static const uint8_t D16 = 32;
static const uint8_t D17 = 33;
static const uint8_t D18 = 21;
static const uint8_t D19 = 34;
static const uint8_t D20 = 36;
static const uint8_t D21 = 39;

static const uint8_t T0 = 4;
static const uint8_t T1 = 0;
static const uint8_t T2 = 2;
static const uint8_t T3 = 15;
static const uint8_t T4 = 13;
static const uint8_t T5 = 12;
static const uint8_t T6 = 14;
static const uint8_t T7 = 27;
static const uint8_t T8 = 33;
static const uint8_t T9 = 32;

static const uint8_t DAC1 = 25;
static const uint8_t DAC2 = 26;

#endif /* Pins_Arduino_h */
